@@ -12,6 +12,10 @@ def in_shape_from(output_shape):
     Returns:
         (int): The input shape associated from a
             `[output_shape, output_shape` SPD tensor.
+
+    Notes:
+        This is the sum of the first n natural numbers
+        https://cseweb.ucsd.edu/groups/tatami/handdemos/sum/
     """
-    input_shape = sum([i for i in range(output_shape + 1)])
+    input_shape = output_shape * (output_shape + 1) // 2
     return input_shape
